%% This code was created using the information in published model on Fantanyl by Bjorkman et al, 1994

%%% Sven Bjorkman, D. Russell Wada, Donald R. Stanski and William F. Ebling. Comparative Physiological...
%%% Pharmacokinetics of Fentanyl and Alfentanil in Rats and Humans Based on Parametric Single-Tissue Models...
%%% J Pharmacokinet Biopharm. 1994 Oct;22(5):381-410

%% DO NOT EDIT THIS FILE
%% Parameter values in the original model

WT = 73; % average weight for man 
Qcad = 6.7; % cardiac output, unit: L/min 
Vven = 3.9; % volume/weight of vein, unit: kg
Vart = 2.0; % volume/weight of artery, unit: kg
Vlun = 0.47; % volume/weight of lung, unit: kg
Qlun = 14.3*Vlun; % blood flow in lung, unit: L/min 
KPlun = 15.3; % partition coeffient for brain, unit: ml/g
KTlun = Qlun/(Vlun*KPlun);
Vbra = 1.4; % volume/weight of brain, unit: kg
Qbra = 0.56*Vbra; % blood flow in brain, unit: L/min 
KPbra = 4; % partition coeffient for brain, unit: ml/g
KTbra = Qbra/(Vbra*KPbra);
Vhea = 0.33; % volume/weight of heart, unit: kg
Qhea = 0.8*Vhea; % blood flow in heart, unit: L/min 
KPhea = 5.1; % partition coeffient for heart, unit: ml/g
KThea = Qhea/(Vhea*KPhea);
Vkid = 0.31; % volume/weight of kidney, unit: kg
Qkid = 4*Vkid; % blood flow in kidney, unit: L/min 
KPkid = 13.7; % partition coeffient for kidney, unit: ml/g
KTkid = Qkid/(Vkid*KPkid);
Vliv = 1.8; % volume/weight of liver, unit: kg
Qliv = 0.96*Vliv; % blood flow in liver, unit: L/min 
KPliv = 4.3; % partition coeffient for liver, unit: ml/g
KTliv = Qliv/(Vliv*KPliv);
Vmus = 30; % volume/weight of muscle, unit: kg
Qmus = 0.038*Vmus; % blood flow in muscle, unit: L/min 
KPmus = 3.5; % partition coeffient for muscle, unit: ml/g
KTmus = Qmus/(Vmus*KPmus);
Vski = 3.3; % volume/weight of skin, unit: kg
Qski = 0.12*Vski; % blood flow in skin, unit: L/min 
KPski = 2.3; % partition coeffient for skin, unit: ml/g
KTski = Qski/(Vski*KPski);
Vfat = 12.5; % volume/weight of fat, unit: kg
Qfat = 0.028*Vfat; % blood flow in fat, unit: L/min 
KPfat = 30.3; % partition coeffient for fat, unit: ml/g
KTfat = Qfat/(Vfat*KPfat);
Vcar = 15.5; % volume/weight of carcass, unit: kg
Qcar = 0.04*Vcar; % blood flow in carcass, unit: L/min 
KPcar = 1; % (not avaialbe) partition coeffient for carcass, unit: ml/g
KTcar = Qcar/(Vcar*KPcar);
Vgut = 1.2; % volume/weight of gut, unit: kg
Vsint = Vgut; % volume/weight of samll intestine, unit: kg
Qgut = 0.83*Vgut; % blood flow in gut, unit: L/min 
Qsint = Qgut; % blood flow in small intestine, unit: L/min 
KPgut = 9; % partition coeffient for gut, unit: ml/g
KTgut = Qgut/(Vgut*KPgut);
Vpas = (0.18+0.10)/2; % average volume/weight of pancreas and spleen, unit: kg
Qpas = (0.6+1.2)/2*Vpas; % average blood flow of pancreas and spleen, unit: L/min 
KPpas = (24.1+31.3)/2; % average partition coeffient of pancreas and spleen, unit: ml/g
KTpas = Qpas/(Vpas*KPpas);
CL12_pas = 2.21*Vpas;% clearance in pancrea + spleen model, unit: L/min (in paper unit was 2.21 ml/min per g)
CL21_pas = CL12_pas; 
Vpas_1 = 0.082*Vpas; % see page 388, volume of 1st cpt in pancreas + spleen model, unit: L (in paper unit was 0.082 ml per g)
Vpas_2 = 22.3*Vpas; % volume of 2nd cpt in pancreas + spleen model, unit: L (in paper unit was 22.3 ml per g)

CL12_hep = 0.35*Vliv; % clearance in liver model, unit: L/min (in paper unit was 0.35 ml/min per g)
CL21_hep = CL12_hep;
CL10_hep = 0.095*Vliv; % clearance in liver model, unit: L/min (in paper unit was 95 ml/min per kg)
Vhep_2 = 8.7*Vliv; % volume of 2nd cpt in liver model, unit: L (in paper unit was 8.7 ml per g)

CL12_gut = 0.89*Vgut;% clearance in gut model, unit: L/min (in paper unit was 0.89 ml/min per g)
CL21_gut = CL12_gut;
CL23_gut = 0.03*Vgut;% clearance in gut model, unit: L/min (in paper unit was 0.03 ml/min per g)
CL32_gut = CL23_gut;
Vgut_1 = Vgut;
Vgut_2 = 6.4*Vgut; % volume of 2nd cpt in gut model, unit: L (in paper unit was 6.4 ml per g)
Vgut_3 = 3.26*Vgut; % volume of 3rd cpt in gut model, unit: L (in paper unit was 3.26 ml per g)

Loss_liver = -(CL12_hep+CL10_hep)/Vliv-KTliv;
S11_to_Liver = KTgut*Vgut/Vliv;
S14_to_Liver = KTpas*Vpas/Vliv;
S16_to_Liver = CL21_hep/Vliv;

Loss_gut_1 = -(Qsint+CL12_gut)/Vgut_1;
Loss_gut_2 = -(CL21_gut+CL23_gut)/Vgut_2;

Loss_pas_1 = -(Qpas+CL12_pas)/Vpas_1;


%% Define the parameter matrix ('K' matrix) of the ODEs in the original model

%ODEs for fentanyl human model (expressed in terms of rate of change in concentration over time) 

% State 1: dCven/dt = ((Cbra*KTbra*Vbra+Chea*KThea*Vhea+Ckid*KTkid*Vkid+Cliv*KTliv*Vliv+Cmus*KTmus*Vmus+Cski*KTski*Vski+Cfat*KTfat*Vfat+Ccar*KTcar*Vcar)-Qcad*Cven)/Vven; % ven for venous
% Clun = Cven; % lun for lung 
% State 2: dCart/dt = (Qcad*Cven-Qcad*Cart)/Vart; % art for arterial
% State 3: dCbra/dt = Qbra*Cart/Vbra-Cbra*KTbra; % bra for brain 
% State 4: dChea/dt = Qhea*Cart/Vhea-Chea*KThea; % hea for heart  
% State 5: dCkid/dt = Qkid*Cart/Vkid-Ckid*KTkid; % kid for kidney 
% State 6: dCliv/dt = (Cgut_1*KTgut*Vgut+Cpas_1*KTpas*Vpas)/Vliv-Cliv*KTliv+(-(CL12_hep+CL10_hep)*Cliv+CL21_hep*Chep_2)/Vliv; % liv for liver, sint for small intestine, 1 more cpt for heptic clearance(see appendix B), hep for hepatic 
% State 7: dCmus/dt = Qmus*Cart/Vmus-Cmus*KTmus; % mus for muscle 
% State 8: dCski/dt = Qski*Cart/Vski-Cski*KTski; % ski for skin 
% State 9: dCfat/dt = Qfat*Cart/Vfat-Cfat*KTfat; % fat for fat 
% State 10: dCcar/dt = Qcar*Cart/Vcar-Ccar*KTcar; % car for carcass 
% State 11: dCgut_1/dt =(-(Qsint+CL12_gut)*Cgut_1+CL21_gut*Cgut_2+Cart*Qsint)/Vgut_1; % single tissue 3-cpt for gut (see appendix A), sint for small intestine (as distribution parameters for sint was used, see page 388) 
% State 12: dCgut_2/dt = (CL12_gut*Cgut_1-(CL21_gut+CL23_gut)*Cgut_2+CL32_gut*Cgut_3)/Vgut_2; 
% State 13: dCgut_3/dt = (CL23_gut*Cgut_2-CL32_gut*Cgut_3)/Vgut_3; 
% State 14: dCpas_1/dt =(-(Qpas+CL12_pas)*Cpas_1+CL21_pas*Cpas_2+Cart*Qpas)/Vpas_1; % single tissues 2-cpt for pancreas and spleen, pas for pancreas and spleen 
% State 15: dCpas_2/dt = (CL12_pas*Cpas_1-CL21_pas*Cpas_2)/Vpas_2; % 2-cpt for heptic clearance(see appendix B), hep for hepatic 
% State 16: dChep_2/dt = (CL12_hep*Cliv-CL21_hep*Chep_2)/Vhep_2; 


% parameter matrix for ODE above (%% K-matrix)

K = [-Qcad/Vven      0      KTbra*Vbra/Vven   KThea*Vhea/Vven   KTkid*Vkid/Vven  KTliv*Vliv/Vven  KTmus*Vmus/Vven  KTski*Vski/Vven  KTfat*Vfat/Vven  KTcar*Vcar/Vven       0           0                       0               0               0                   0
    Qcad/Vart    -Qcad/Vart        0               0                   0               0                0                 0                0               0               0           0                       0               0               0                   0  
        0        Qbra/Vbra         -KTbra          0                   0               0                0                 0                0               0               0           0                       0               0               0                   0
        0        Qhea/Vhea         0           -KThea                  0               0                0                 0                0               0               0           0                       0               0               0                   0
        0        Qkid/Vkid         0               0                 -KTkid            0                0                 0                0               0               0           0                       0               0               0                   0
        0            0             0               0                   0           Loss_liver           0                 0                0               0           S11_to_Liver    0                       0          S14_to_Liver         0              S16_to_Liver 
        0        Qmus/Vmus         0               0                   0               0             -KTmus               0                0               0               0           0                       0               0               0                   0
        0        Qski/Vski         0               0                   0               0                0              -KTski              0               0               0           0                       0               0               0                   0
        0        Qfat/Vfat         0               0                   0               0                0                 0             -KTfat             0               0           0                       0               0               0                   0
        0        Qcar/Vcar         0               0                   0               0                0                 0                0               -KTcar          0           0                       0               0               0                   0
        0       Qsint/Vgut_1       0               0                   0               0                0                 0                0               0           Loss_gut_1      CL21_gut/Vgut_1         0               0               0                   0
        0            0             0               0                   0               0                0                 0                0               0         CL12_gut/Vgut_2   Loss_gut_2           CL32_gut/Vgut_2    0               0                   0
        0            0             0               0                   0               0                0                 0                0               0               0           CL23_gut/Vgut_3     -CL32_gut/Vgut_3    0               0                   0
        0       Qpas/Vpas_1        0               0                   0               0                0                 0                0               0               0           0                       0              Loss_pas_1       CL21_pas/Vpas_1     0
        0            0             0               0                   0               0                0                 0                0               0               0           0                       0              CL12_pas/Vpas_2  -CL21_pas/Vpas_2    0
        0            0             0               0                   0        CL12_hep/Vhep_2         0                 0                0               0               0           0                       0              0                 0                  -CL21_hep/Vhep_2];

    