%% An example to simplify a Physiologically Based Pharmacokinetic Model of Fantanyl in Human (iv bolus)
%% These files were created by Shan Pan, Vittal Shivva and Stephen Duffull
%% Dec 2014
%% DO NOT EDIT THIS FILE
%% This file calls three other files which perform various jobs of model simplification of this example model

clear all
close all
clc
tic

warning off

%% Get model and parameter values

Model_parameter_values


%% Set Design variables

Dose = 750; % microgram, intravenous fentanyl (Note: in original paper infusion was given over 5 mins, see page 398)  

TT = [0:0.05:360]; % time range for 6 hrs, unit: min

IC = [Dose/Vven;zeros(15,1)]; % initial conditions for each state (here initial conditions are defined as concentraion and not in amounts)


%% Compute concentrations from the original model

Conc = ME_solution(K,IC,TT);


%% Choose a lumping matrix

Lumping_matrix ;  % Call the lumping matrix to create a simplified version of the model by lumping some of the states

[m,n] = size(M);  % size of the lumping matrix

Minv=pinv(M);     % Pseudoinverse of the lumping matrix
 % if using Freemat (ver 4.2) then write as Minv=(pinv(M)')'

K_hat=M*K*Minv;   % K matrix (parameter matrix) in the lumped model

IC_hat=M*IC;      % Initial conditions of the lumped states in the lumped matrix


%% Compute concentrations from lumped model

Conc_hat = ME_solution(K_hat,IC_hat,TT); 


%% outputs 

% original model
figure (1)
semilogy(TT,Conc(2,:),'b-','LineWidth',2); % '2' for the arterial blood 
hold on
xlim([0 360])
ylim([0.01 100])
xlabel('Time (min)','fontsize',24)
ylabel('Concentraion in arterial blood (ug/L)','fontsize',24)
title('Original model','fontsize',24)
set(gca,'fontsize',20)
hold off

% lumped model
figure (2)
semilogy(TT,Conc_hat(2,:),'r--','LineWidth',2); % '2' for the arterial blood 
hold on
xlim([0 360])
ylim([0.01 100])
xlabel('Time (min)','fontsize',24)
ylabel('Concentraion in arterial blood (ug/L)','fontsize',24)
title('Lumped model','fontsize',24)
set(gca,'fontsize',20)
hold off

% Percent relative difference between both models
figure(3)
subplot(1,2,1)
semilogy(TT,Conc(2,:),'b-','LineWidth',2); % '2' for the arterial blood 
hold on
semilogy(TT,Conc_hat(2,:),'r--','LineWidth',2); % '2' for the arterial blood 
xlim([0 360])
ylim([0.01 100])
xlabel('Time (min)','fontsize',24)
ylabel('Concentraion in arterial blood (ug/L)','fontsize',24)
set(gca,'fontsize',20)
hold off
legend('Original model','Lumped model')

subplot(1,2,2)
plot(TT,abs((Conc(2,:)-Conc_hat(2,:))./Conc(2,:)*100),'b','LineWidth',2)
xlabel('Time (min)','fontsize',24)
ylabel('Absolute relative difference (%)','fontsize',24)
set(gca,'fontsize',20)

%%% Congratulations!!!! You have completed this example
%%% You can try lumping other combinations by changing only 'M' matrix in Lumping_matrix.m file
%%% You donot need to change anything else anywhere in any other file

toc 